# Gym

## Description

This skill trains an RL algorithm using OpenAI Gym.

This skill is part of the Fetch.ai Gym demo. It trains a reinforcement learning (RL) algorithm using OpenAI Gym. It demonstrate how to wrap a RL agent in a skill by decoupling the RL agent from the gym.Env, allowing them to run in separate execution environments.

## Behaviours

## Handlers

* gym: handles ml_trade messages for negotiating the terms of trade


## Links

* <a href="https://docs.fetch.ai/aea/gym-skill/" target="_blank">Gym Demo</a>
* <a href="https://docs.fetch.ai/aea/gym-example/" target="_blank">Gym Example</a>
* <a href="https://gym.openai.com" target="_blank">OpenAI Gym</a>